/*
 * This file is part of tcpflow by Jeremy Elson <jelson@circlemud.org>
 * Initial Release: 7 April 1999.
 *
 * This source code is under the GNU Public License (GPL).  See
 * LICENSE for details.
 *
 * $Id: flow.c,v 1.6 1999/04/13 01:38:11 jelson Exp $
 *
 * $Log: flow.c,v $
 * Revision 1.6  1999/04/13 01:38:11  jelson
 * Added portability features with 'automake' and 'autoconf'.  Added AUTHORS,
 * NEWS, README, etc files (currently empty) to conform to GNU standards.
 *
 * Various portability fixes, including the FGETPOS/FSETPOS macros; detection
 * of header files using autoconf; restructuring of debugging code to not
 * need vsnprintf.
 *
 */

#include "tcpflow.h"
#include <assert.h>
#include <iostream>
#include <sstream>


int32_t flow_t::NO_VLAN = -1;

std::string flow_t::filename()
{
    char buf[1024];
    char srcstr[INET6_ADDRSTRLEN+1];
    char dststr[INET6_ADDRSTRLEN+1];
    std::stringstream ss;

    if(opt_format_ISOtimestamp) {
	strftime(buf,sizeof(buf),"%FT%TZ",gmtime(&tstart.tv_sec));
	ss << buf;
    }

    if(opt_format_timestamp) {
	ss << tstart.tv_sec << "T";
    }

    switch(family){
    default:
    case AF_INET:
	snprintf(buf,sizeof(buf),
		 "%03d.%03d.%03d.%03d.%05d-%03d.%03d.%03d.%03d.%05d",
		 src.addr[0], src.addr[1], src.addr[2], src.addr[3], sport,
		 dst.addr[0], dst.addr[1], dst.addr[2], dst.addr[3], dport);
	ss << buf;
	break;
    case AF_INET6:
	snprintf(buf,sizeof(buf),
		 "%s.%05d-%s.%05d",
		 inet_ntop(family, src.addr, srcstr, sizeof(srcstr)),
		 sport,
		 inet_ntop(family, dst.addr, dststr, sizeof(dststr)),
		 dport);
	ss << buf;
    }

    if(vlan!=NO_VLAN){
	ss << "--" << vlan;
    }
    if(opt_format_connection_counter || connection_count>0){
	ss << "c" << connection_count;
    }

    return ss.str();
}





